@@ -43,7 +43,6 @@ OC.L10N.register(
     "Week {number} of {year}" : "Selmana {number} del {year}",
     "Daily" : "Caldía",
     "Weekly" : "Selmanalmente",
-    "today" : "güei",
     "When shared show full event" : "Amosar l'eventu completu al compartir",
     "When shared show only busy" : "Amosar namás ocupáu al compartir",
     "When shared hide this event" : "Anubrir l'eventu al compartir",
@@ -56,7 +55,6 @@ OC.L10N.register(
     "Presentation" : "Presentación",
     "Office" : "Oficina",
     "Mail" : "Corréu",
-    "Play" : "Reproducir",
     "Global" : "Global"
 },
 "nplurals=2; plural=(n != 1);");
