@@ -28,10 +28,8 @@ OC.L10N.register(
     "Close" : "Bağla",
     "Daily" : "Günlük",
     "Weekly" : "Həftəlik",
-    "today" : "Bu gün",
     "Location" : "Yerləşdiyiniz ünvan",
     "Description" : "Açıqlanma",
-    "Mail" : "Məktub",
-    "Play" : "Oxu"
+    "Mail" : "Məktub"
 },
 "nplurals=2; plural=(n != 1);");
