@@ -5,7 +5,6 @@ OC.L10N.register(
     "Provided email-address is not valid" : "Uppgefið tölvupóstfang er ekki gilt",
     "%s has published the calendar »%s«" : "%s gaf út dagatalið »%s«",
     "Unexpected error sending email. Please contact your administrator." : "Óvænt vandamál kom upp við að senda tölvupóst. Hafðu samband við kerfisstjóra.",
-    "Successfully sent email to " : "Tókst að senda tölvupóst til",
     "Hello," : "Halló,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Við vildum láta þig vita að %s gaf út dagatalið »%s«.",
     "Open »%s«" : "Opna »%s«",
@@ -77,6 +76,7 @@ OC.L10N.register(
     "Creating subscription …" : "Útbý áskrift …",
     "An error occurred, unable to create the calendar." : "Villa kom upp, gat ekki búið til dagatalið.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Skráðu inn gilda slóð (starting with http://, https://, webcal://, or webcals://)",
+    "Untitled event" : "Ónefndur atburður",
     "Import calendars" : "Flytja inn dagatöl",
     "Please select a calendar to import into …" : "Veldu dagatal til að flytja inn í …",
     "Filename" : "Skráarheiti",
@@ -131,25 +131,17 @@ OC.L10N.register(
     "_week_::_weeks_" : ["vika","vikur"],
     "No reminders yet" : "Engar áminningar ennþá",
     "Availability of attendees, resources and rooms" : "Framboð á þátttakendum, tilföngum og herbergjum",
+    "Free" : "Laus",
     "Busy (tentative)" : "Upptekinn (með fyrirvara)",
     "Busy" : "Upptekinn",
     "Out of office" : "Ekki á staðnum",
     "Unknown" : "Óþekkt",
-    "{name} accepted your invitation." : "{name} hefur samþykkt boð þitt.",
-    "{name} accepted {organizerName}'s invitation." : "{name} hefur samþykkt boð frá {organizerName}.",
-    "{name} declined your invitation." : "{name} hafnaði boði þínu.",
-    "{name} declined {organizerName}'s invitation." : "{name} hefur hafnaði boði frá {organizerName}.",
-    "{name} marked their participation as tentative." : "{name} merktu við þáttöku sína með fyrirvara as tentative.",
-    "{name} did not respond to your invitation yet." : "{name} hefur ekki svarað boðinu þínu ennþá.",
-    "{name} did not respond to {organizerName}'s invitation yet." : "{name} hefur ekki svarað boðinu frá {organizerName} ennþá.",
     "Show busy times" : "Sýna upptekinn tíma",
-    "Send e-mail" : "Senda tölvupóst",
     "Chairperson" : "Fundarstjóri",
     "Required participant" : "Nauðsynlegur þáttakandi",
     "Optional participant" : "Aukaþáttakandi",
     "Non-participant" : "Ekki þáttakandi",
     "Remove attendee" : "Fjarlægja þáttakanda",
-    "Search for e-mails, users, contacts, resources or rooms" : "Leita að tölvupósti, notendum, tengiliðum, aðföngum eða fundarsölum",
     "No match found" : "Fann engar samsvaranir",
     "No attendees yet" : "Engir þáttakendur ennþá",
     "(organizer)" : "(skipuleggjandi)",
@@ -234,11 +226,8 @@ OC.L10N.register(
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "í {monthNames} þann {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "þangað til {untilDate}",
     "_%n time_::_%n times_" : ["%n sinni","%n sinnum"],
-    "Untitled event" : "Ónefndur atburður",
     "Untitled task" : "Ónefnt verkefni",
     "Please ask your administrator to enable the Tasks App." : "Biddu kerfisstjórann þinn um að virkja verkefnasorritið (Tasks).",
-    "next year" : "á næsta ári",
-    "today" : "í dag",
     "_+%n more_::_+%n more_" : ["+%n til viðbótar","+%n til viðbótar"],
     "When shared show" : "Þegar er deilt, birta ",
     "When shared show full event" : "Þegar er deilt, birta allan atburð",
@@ -256,7 +245,6 @@ OC.L10N.register(
     "Confirmation about the overall status of the event." : "Staðfesting á almennri stöðu atburðarins.",
     "Show as" : "Birta sem",
     "Take this event into account when calculating free-busy information." : "Taka þennan atburð með í reikninga á laus/upptekinn upplýsingum.",
-    "Free" : "Laus",
     "Categories" : "Flokkar",
     "Categories help you to structure and organize your events." : "Flokkar hjálpa þér við að greina og skipuleggja atburði.",
     "Search or add categories" : "Leita eða bæta við flokkum",
@@ -283,14 +271,10 @@ OC.L10N.register(
     "Review" : "Yfirfara",
     "Office" : "Skrifstofa",
     "Contributor week" : "Vika með þátttakendum",
-    "Party" : "Partý",
-    "Celebration" : "Hátíðahöld",
     "Mail" : "Póstur",
     "Soccer" : "Fótbolti",
     "Football" : "Ruðningsbolti",
     "Gaming" : "Spilun",
-    "Play" : "Spila",
-    "Game" : "Leikur",
     "Drive" : "Keyra",
     "Bicycle" : "Reiðhjól",
     "Cycle" : "Hjóla",
@@ -344,6 +328,8 @@ OC.L10N.register(
     "Lecture" : "Fyrirlestur",
     "Seminar" : "Námskeið",
     "Photograph" : "Ljósmynd",
+    "Party" : "Partý",
+    "Celebration" : "Hátíðahöld",
     "Celebrate" : "Fagna",
     "Shopping" : "Versla",
     "Skate" : "Skautar",
