@@ -5,7 +5,7 @@ OC.L10N.register(
     "Provided email-address is not valid" : "メールアドレスが有効ではありません",
     "%s has published the calendar »%s«" : "%sをカレンダー »%s«に登録しました",
     "Unexpected error sending email. Please contact your administrator." : "メール送信時の予期せぬエラー。管理者に連絡してください。",
-    "Successfully sent email to " : "メールを次の宛先へ送信しました：",
+    "Successfully sent email to %1$s" : "%1$sへのメール送信に成功しました",
     "Hello," : "こんにちは。",
     "We wanted to inform you that %s has published the calendar »%s«." : "%sがカレンダー»%s«に登録されましたのでお知らせします。",
     "Open »%s«" : "»%s«を開く",
@@ -78,6 +78,7 @@ OC.L10N.register(
     "Creating subscription …" : "購読を作成中 …",
     "An error occurred, unable to create the calendar." : "エラーが発生したため、カレンダーを作成できません。",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "有効なリンクを入力してください（http:// や https:// 、webcal:// または webcals:// のいずれかで始まる必要があります）",
+    "Untitled event" : "無題のイベント",
     "Could not update calendar order." : "カレンダーの順番を更新できません。",
     "Import calendars" : "カレンダーのインポート",
     "Please select a calendar to import into …" : "インポートするカレンダーを選択してください …",
@@ -134,34 +135,25 @@ OC.L10N.register(
     "_day_::_days_" : ["日"],
     "_week_::_weeks_" : ["週"],
     "No reminders yet" : "まだリマインダーはありません",
+    "Free" : "無料",
     "Busy (tentative)" : "ビジー (暫定)",
     "Busy" : "ビジー",
     "Out of office" : "オフィス外",
     "Unknown" : "不明",
-    "{name} accepted your invitation." : "{name}が招待を受け入れました。",
-    "{name} accepted {organizerName}'s invitation." : "{name}が{organizerName}の招待を受け入れました。",
-    "{name} declined your invitation." : "{name}が招待を辞退しました。",
-    "{name} declined {organizerName}'s invitation." : "{name}が{organizerName}の招待を辞退しました。",
-    "{name} has delegated their invitation." : "{name}が招待を委任されました。",
-    "{name} marked their participation as tentative." : "{name}が参加を暫定的とマークしました。",
-    "{name} did not respond to your invitation yet." : "{name}は招待にまだ返答していません。",
-    "{name} did not respond to {organizerName}'s invitation yet." : "{name}は{organizerName}の招待にまだ応答していません。",
     "Create Talk room for this event" : "このイベントに通話ルームを作成する",
     "Error creating Talk room" : "通話ルームの作成に失敗しました",
-    "Send e-mail" : "メールを送信",
+    "Send email" : "メールを送信",
     "Chairperson" : "主宰者",
     "Required participant" : "参加必須",
     "Optional participant" : "任意参加",
     "Non-participant" : "非参加",
     "Remove attendee" : "出席者を削除",
-    "Search for e-mails, users, contacts, resources or rooms" : "メール、ユーザー、連絡先、リソース、またはルームを検索する",
     "No match found" : "一致するものが見つかりません",
     "No attendees yet" : "出席者はまだいません",
     "(organizer)" : "（主催者）",
     "Remove color" : "色を削除",
     "Event title" : "イベントタイトル",
     "All day" : "終日",
-    "Can not modify all-day setting for events that are part of a recurrence-set." : "繰り返しの一部であるイベントの終日設定を変更することはできません。",
     "from {startDate}" : "{startDate}から",
     "from {startDate} at {startTime}" : "{startDate}の{startTime}から",
     "to {endDate}" : "{endDate}まで",
@@ -248,17 +240,9 @@ OC.L10N.register(
     "_Every %n month_::_Every %n months_" : ["%n月ごと"],
     "_Every %n year_::_Every %n years_" : ["%n年ごと"],
     "_%n time_::_%n times_" : ["%n回"],
-    "Untitled event" : "無題のイベント",
     "Untitled task" : "タイトルなしタスク",
     "Please ask your administrator to enable the Tasks App." : "「タスク」アプリを有効化のために、管理者さんにお問い合わせください",
-    "prev" : "前へ",
-    "next" : "次へ",
-    "prev year" : "前の年へ",
-    "next year" : "来年",
-    "today" : "今日",
-    "list" : "リスト",
     "W" : "W",
-    "all-day" : "終日",
     "No events to display" : "表示するイベントはありません",
     "No events" : "イベントはありません",
     "When shared show full event" : "共有時にすべてのイベントを表示",
@@ -273,7 +257,6 @@ OC.L10N.register(
     "Tentative" : "暫定的",
     "Canceled" : "キャンセル済み",
     "Show as" : "として表示",
-    "Free" : "無料",
     "Categories" : "カテゴリ",
     "Search or add categories" : "カテゴリを検索または追加",
     "Add this as a new category" : "これを新しいカテゴリーとして追加",
@@ -294,14 +277,10 @@ OC.L10N.register(
     "Meet" : "打ち合わせ",
     "Review" : "レビュー",
     "Office" : "オフィス",
-    "Party" : "パーティー",
-    "Celebration" : "祝",
     "Mail" : "メール",
     "Soccer" : "サッカー",
     "Football" : "フットボール",
     "Gaming" : "ゲーム",
-    "Play" : "再生",
-    "Game" : "ゲーム",
     "Drive" : "ドライブ",
     "Bicycle" : "自転車",
     "Cycle" : "自転車",
@@ -354,6 +333,8 @@ OC.L10N.register(
     "Lecture" : "講義",
     "Seminar" : "ゼミ",
     "Photograph" : "写真",
+    "Party" : "パーティー",
+    "Celebration" : "祝",
     "Celebrate" : "お祝い",
     "Shopping" : "買い物",
     "Skate" : "スケート",
