@@ -46,8 +46,6 @@ OC.L10N.register(
     "Week {number} of {year}" : "კვირა {number} {year}-დან",
     "Daily" : "ყოველდღიური",
     "Weekly" : "ყოველკვირეული",
-    "next year" : "შემდეგი წელი",
-    "today" : "დღეს",
     "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
     "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
     "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა",
@@ -58,7 +56,6 @@ OC.L10N.register(
     "Tentative" : "საცდელი",
     "Categories" : "კატეგორიები",
     "Mail" : "ფოსტა",
-    "Play" : "დაკვრა",
     "Global" : "გლობალური"
 },
 "nplurals=2; plural=(n!=1);");
