@@ -5,7 +5,6 @@ OC.L10N.register(
     "Provided email-address is not valid" : "Адресата на е-пошта не е правилно внесена",
     "%s has published the calendar »%s«" : "%s Објави календар »%s«",
     "Unexpected error sending email. Please contact your administrator." : "Неочекувана грешка при испраќање на е-пошта. Контактирајте го администраторот.",
-    "Successfully sent email to " : "Успешно испратена е-пошта до",
     "Hello," : "Здраво,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Сакаме да те информираме дека %s објави календар »%s«.",
     "Open »%s«" : "Отвори »%s«",
@@ -78,6 +77,7 @@ OC.L10N.register(
     "Creating subscription …" : "Креирање претплата  …",
     "An error occurred, unable to create the calendar." : "Настана грешка, неможе да се креира календар.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Внесете валиден линк (започнувајчи со http://, https://, webcal://, или webcals://)",
+    "Untitled event" : "Неименуван настан",
     "Could not update calendar order." : "Неможе да се ажурира редоследот на календарите.",
     "Import calendars" : "Увези календари",
     "Please select a calendar to import into …" : "Изберете календар за да направите увоз во него …",
@@ -102,6 +102,7 @@ OC.L10N.register(
     "Day view" : "Дневен преглед",
     "Week view" : "Неделен преглед",
     "Month view" : "Месечен преглед",
+    "List view" : "Листа",
     "Actions" : "Акции",
     "Create event" : "Креирај настан",
     "Show shortcuts" : "Прикажи кратенки",
@@ -137,29 +138,22 @@ OC.L10N.register(
     "_week_::_weeks_" : ["недела","недели"],
     "No reminders yet" : "Сеуште нема потсетници",
     "Availability of attendees, resources and rooms" : "Достапност на присутните, ресурси и соби",
+    "Free" : "Слободен",
     "Busy (tentative)" : "Зафатен (привремено)",
     "Busy" : "Зафатен",
     "Out of office" : "Надвор од канцеларија",
     "Unknown" : "Непознат",
-    "{name} accepted your invitation." : "{name} ја прифати вашата покана.",
-    "{name} accepted {organizerName}'s invitation." : "{name} ја прифати поканата од {organizerName}.",
-    "{name} declined your invitation." : "{name} ја одби вашата покана.",
-    "{name} declined {organizerName}'s invitation." : "{name} ја одби поканата од {organizerName}.",
-    "{name} has delegated their invitation." : "{name} одговори на неговата покана.",
-    "{name} marked their participation as tentative." : "{name} го означи неговото учество како пробно.",
-    "{name} did not respond to your invitation yet." : "{name} сеуште нема одговорено на поканата.",
-    "{name} did not respond to {organizerName}'s invitation yet." : "{name} сеуште нема одговорено на поканата од {organizerName}.",
     "Create Talk room for this event" : "Креирај соба за разговор за овој настан",
     "Show busy times" : "Прикажи ги зафатените термини",
     "Successfully appended link to talk room to description." : "Успешно додаден линк од собата за разговор во описот.",
     "Error creating Talk room" : "Грешка при креирање на соба за разговор",
-    "Send e-mail" : "Испрати пошта",
+    "Send email" : "Испрати е-пошта",
     "Chairperson" : "Претседавач",
     "Required participant" : "Задолжителен учесник",
     "Optional participant" : "Незадолжителен учесник",
     "Non-participant" : "Не-учесник",
     "Remove attendee" : "Откажи присутност",
-    "Search for e-mails, users, contacts, resources or rooms" : "Пребарувај за е-пошти, корисници, контакти, ресурси или соби",
+    "Search for emails, users, contacts, resources or rooms" : "Пребарувај за е-пошти, корисници, контакти, ресурси или соби",
     "No match found" : "Нема совпаѓања",
     "No attendees yet" : "Сè уште нема присутни",
     "(organizer)" : "(organizer)",
@@ -276,17 +270,9 @@ OC.L10N.register(
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "во {monthNames} на {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "до {untilDate}",
     "_%n time_::_%n times_" : ["уште еднаш","%n пати"],
-    "Untitled event" : "Неименуван настан",
     "Untitled task" : "Неименувана задача",
     "Please ask your administrator to enable the Tasks App." : "Замолете го сервер администраторот да ја овозможи апликацијата задачи.",
-    "prev" : "предходна",
-    "next" : "следна",
-    "prev year" : "предходна година",
-    "next year" : "следниот месец",
-    "today" : "денес",
-    "list" : "лист",
     "W" : "Н",
-    "all-day" : "Цели денови",
     "%n more" : "%n други",
     "No events to display" : "Нема настани за приказ",
     "_+%n more_::_+%n more_" : ["+%n друг","+%n други"],
@@ -310,7 +296,6 @@ OC.L10N.register(
     "Confirmation about the overall status of the event." : "Потврда за целокупниот статус на настанот.",
     "Show as" : "Прикажи како",
     "Take this event into account when calculating free-busy information." : "Го има во предвид овој настан при пресметување на информации за слободен-зафатен.",
-    "Free" : "Слободен",
     "Categories" : "Категории",
     "Categories help you to structure and organize your events." : "Категориите ви помагаат да ги структурирате и организирате вашите настани.",
     "Search or add categories" : "Барај или додади категории",
@@ -335,14 +320,10 @@ OC.L10N.register(
     "Retrospective" : "Ретроспектива",
     "Review" : "Преглед",
     "Office" : "Канцеларија",
-    "Party" : "Забава",
-    "Celebration" : "Прослава",
     "Mail" : "Електронска пошта",
     "Soccer" : "Фудбал",
     "Football" : "Фудбал",
     "Gaming" : "Играње",
-    "Play" : "Слајдшоу",
-    "Game" : "Игра",
     "Drive" : "Возење",
     "Bicycle" : "Велосипед",
     "Cycle" : "Циклус",
@@ -396,6 +377,8 @@ OC.L10N.register(
     "Lecture" : "Читање",
     "Seminar" : "Семинар",
     "Photograph" : "Фотографија",
+    "Party" : "Забава",
+    "Celebration" : "Прослава",
     "Celebrate" : "Прослава",
     "Shopping" : "Купување",
     "Skate" : "Скејтбординг",
