@@ -5,7 +5,7 @@ OC.L10N.register(
     "Provided email-address is not valid" : "Zadaná adresa e-mailu nie je platná",
     "%s has published the calendar »%s«" : "Používateľ %s zverejnil kalendár %s",
     "Unexpected error sending email. Please contact your administrator." : "Neočakávaná chyba počas odosielania e-mailu. Obráťte sa na správcu",
-    "Successfully sent email to " : "E-mail bol úspešne odoslaný na",
+    "Successfully sent email to %1$s" : "E-mail bol úspešne odoslaný pre %1$s",
     "Hello," : "Ahoj,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Chceme vás upozorniť, že používateľ %s zverejnil kalendár %s",
     "Open »%s«" : "Otvoriť »%s«",
@@ -78,6 +78,14 @@ OC.L10N.register(
     "Creating subscription …" : "Vytvára sa odber …",
     "An error occurred, unable to create the calendar." : "Vyskytla sa chyba, nie je možné vytvoriť kalendár.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vkladajte platné odkazy (musia sa začínať http://, https://, webcal:// alebo webcals://)",
+    "Trash bin" : "Kôš",
+    "Name" : "Názov",
+    "Deleted" : "Zmazané",
+    "Restore" : "Obnoviť",
+    "Delete permanently" : "Zmazať  natrvalo",
+    "Untitled event" : "Udalosť bez názvu",
+    "Could not load deleted calendars and objects" : "Nie je možné načítať zmazané kalendáre a objekty",
+    "Could not restore calendar or event" : "Nie je možné obnoviť kalendár alebo udalosť",
     "Could not update calendar order." : "Poradie kalendára sa nepodarilo aktualizovať.",
     "Import calendars" : "Import kalendára",
     "Please select a calendar to import into …" : "Vyberte kalendár do ktorého importovať …",
@@ -102,6 +110,7 @@ OC.L10N.register(
     "Day view" : "Denné zobrazenie",
     "Week view" : "Týždenné zobrazenie",
     "Month view" : "Mesačné zobrazenie",
+    "List view" : "Zobraziť ako zoznam",
     "Actions" : "Akcie",
     "Create event" : "Vytvoriť udalosť",
     "Show shortcuts" : "Zobraziť skratky",
@@ -111,10 +120,12 @@ OC.L10N.register(
     "Limit visible events per view" : "Obmedziť viditeľné udalosti v jednotlivých pohľadoch",
     "Show weekends" : "Zobraziť víkendy",
     "Show week numbers" : "Zobraziť čísla týždňov",
+    "Default reminder" : "Predvolená pripomienka",
     "Copy primary CalDAV address" : "Kopírovať primárnu CalDAV adresu",
     "Copy iOS/macOS CalDAV address" : "Kopírovať iOS/macOS CalDAV adresu",
     "Show keyboard shortcuts" : "Zobraziť klávesové skratky",
     "Settings & import" : "Nastavenia a import",
+    "No reminder" : "Žiadna pripomienka",
     "CalDAV link copied to clipboard." : "Odkaz CalDAV skopírovaný do schránky.",
     "CalDAV link could not be copied to clipboard." : "Odkaz CalDAV nebolo možné skopírovať do schránky.",
     "before at" : "pred o",
@@ -137,36 +148,32 @@ OC.L10N.register(
     "_week_::_weeks_" : ["týždeň","týždne","týždňov","týždňov"],
     "No reminders yet" : "Žiadne pripomienky",
     "Availability of attendees, resources and rooms" : "Dostupnosť účastníkov, zdrojov a miestností",
+    "{organizer} (organizer)" : "{organizer} (organizátor)",
+    "Free" : "Voľný",
     "Busy (tentative)" : "Zaneprázdnený (predbežne)",
     "Busy" : "Zaneprázdnený",
     "Out of office" : "Mimo kancelárie",
     "Unknown" : "Neznámy",
-    "{name} accepted your invitation." : "{name} prijal vaše pozvanie.",
-    "{name} accepted {organizerName}'s invitation." : "{name} prijal pozvanie od {organizerName}.",
-    "{name} declined your invitation." : "{name} zamietol vaše pozvanie.",
-    "{name} declined {organizerName}'s invitation." : "{name} zamietol pozvanie od {organizerName}.",
-    "{name} has delegated their invitation." : "{name} delegoval ich pozvanie.",
-    "{name} marked their participation as tentative." : "Používateľ {name} označil svoju účasť ako predbežnú.",
-    "{name} did not respond to your invitation yet." : "{name} zatiaľ neodpovedal na vaše pozvanie.",
-    "{name} did not respond to {organizerName}'s invitation yet." : "{name} zatiaľ neodpovedal na pozvanie od {organizerName}.",
+    "Available." : "Dostupné.",
+    "Not available." : "Nedostupné.",
+    "Invitation accepted." : "Pozvánka prijatá.",
+    "Invitation sent." : "Pozvánka odoslaná.",
     "Create Talk room for this event" : "Vytvoriť pre túto udalosť miestnosť v Talk",
     "Show busy times" : "Zobraziť časy zaneprázdnenosti",
     "Successfully appended link to talk room to description." : "Do popisu bol úspešne pridaný odkaz na miestnosť v Talk",
     "Error creating Talk room" : "Chyba pri vytváraní miestnosti v Talk",
-    "Send e-mail" : "Poslať e-mail",
+    "Send email" : "Odoslať email",
     "Chairperson" : "Predseda",
     "Required participant" : "Požadovaná účasť",
     "Optional participant" : "Nepovinná účasť",
     "Non-participant" : "Bez účasti",
     "Remove attendee" : "Odstrániť účastníka",
-    "Search for e-mails, users, contacts, resources or rooms" : "Vyhľadať emaily, užívateľov, kontakty, zdroje alebo miestnosti ",
     "No match found" : "Nenašla sa žiadna zhoda",
     "No attendees yet" : "Zatiaľ žiadni účastníci",
     "(organizer)" : "(organizátor)",
     "Remove color" : "Odobrať farbu",
     "Event title" : "Názov udalosti",
     "All day" : "Celý deň",
-    "Can not modify all-day setting for events that are part of a recurrence-set." : "Pri opakovaných udalostiach nie je možné meniť niektoré nastavenia.",
     "from {startDate}" : "od {startDate}",
     "from {startDate} at {startTime}" : "od {startDate} o {startTime}",
     "to {endDate}" : "do {endDate}",
@@ -177,7 +184,6 @@ OC.L10N.register(
     "on date" : "dňa",
     "after" : "po",
     "_time_::_times_" : ["krát","krát","krát","krát"],
-    "This event is the recurrence-exception of a recurrence-set. You can not add a recurrence-rule to it." : "Táto udalosť je výnimkou v opakovanej udalosti. Nie je možné k nej pridať opakovanie.",
     "first" : "prvý",
     "third" : "tretie",
     "fourth" : "štvrté",
@@ -219,6 +225,7 @@ OC.L10N.register(
     "Personal" : "Osobné",
     "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Automatická detekcia časového pásma určila, že vaše časové pásmo je UTC.\nJe to pravdepodobne výsledok bezpečnostných opatrení vášho webového prehliadača.\nNastavte časové pásmo manuálne v nastaveniach kalendára.",
     "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "Vami nastavené časové pásmo ({timezoneId}) sa nenašlo. Nastavené bolo UTC.\nZmeňte v nastaveniach svoje časové pásmo a nahláste tento problém.",
+    "No more events today" : "Dnes žiadne ďalšie udalosti",
     "No upcoming events" : "Žiadne nadchádzajúce udalosti",
     "Create a new event" : "Vytvoriť novú udalosť",
     "[Today]" : "[Dnes]",
@@ -276,11 +283,13 @@ OC.L10N.register(
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "v {monthNames} v {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "do {untilDate}",
     "_%n time_::_%n times_" : ["%n raz","%n raz","%n raz","%n raz"],
-    "Untitled event" : "Udalosť bez názvu",
     "Untitled task" : "Úloha bez názvu",
     "Please ask your administrator to enable the Tasks App." : "Požiadajte svojho správcu, aby povolil aplikáciu Úlohy.",
-    "next year" : "budúci rok",
-    "today" : "dnes",
+    "Prev" : "Predch",
+    "Next" : "Ďalšie",
+    "Year" : "Rok",
+    "%n more" : "%n ďalších",
+    "No events to display" : "Žiadne udalosti k zobrazeniu",
     "_+%n more_::_+%n more_" : ["+%n ďalší","+%n ďalší","+%n ďalší","+%n ďalších"],
     "No events" : "Žiadne udalosti",
     "When shared show" : "Pri zdieľaní zobraziť",
@@ -299,7 +308,6 @@ OC.L10N.register(
     "Confirmation about the overall status of the event." : "Potvrdenie o celkovom stave udalosti.",
     "Show as" : "Zobrazovať ako",
     "Take this event into account when calculating free-busy information." : "Zohľadniť túto udalosť pri určovaní zaneprázdnených/voľných hodín. ",
-    "Free" : "Voľný",
     "Categories" : "Kategórie",
     "Categories help you to structure and organize your events." : "Kategórie pomáhajú udržiavať prehľad v udalostiach a štruktúrovať ich.",
     "Search or add categories" : "Hľadať alebo pridať kategórie",
@@ -327,18 +335,15 @@ OC.L10N.register(
     "Review" : "Preskúmať",
     "Office" : "Kancelária",
     "Contributor week" : "Týždeň prispievateľov",
-    "Party" : "Párty",
-    "Celebration" : "Oslava",
     "Mail" : "Pošta",
     "Soccer" : "futbal",
     "Football" : "Futbal",
     "Gaming" : "Hranie",
-    "Play" : "Hrať sa",
-    "Game" : "Hra",
     "Drive" : "Šoférovať",
     "Bicycle" : "Bicykel",
     "Cycle" : "Bicyklovať",
     "Biking" : "Bicyklovanie",
+    "Bike" : "Bycikel",
     "Podcast" : "Podcast",
     "Basketball" : "Basketbal",
     "Fishing" : "Rybačka",
@@ -388,6 +393,8 @@ OC.L10N.register(
     "Lecture" : "Prednáška",
     "Seminar" : "Seminár",
     "Photograph" : "Fotografovať",
+    "Party" : "Párty",
+    "Celebration" : "Oslava",
     "Celebrate" : "Oslava",
     "Shopping" : "Nakupovanie",
     "Skate" : "Korčulovanie",
